@@ -8,7 +8,7 @@ use URI::Escape;
 use Encode;
 
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 my %lang_pairs = (
@@ -138,13 +138,12 @@ sub translate {
     }
     
     my $translated = _fix_translated($response->{'_content'});
+    $translated = decode_utf8($translated);
     
     if ($self->{output} eq 'marked_text') {
         
         if ($self->{store_unknown}) {
             
-            $translated = decode_utf8($translated);
-            
             # store unknown words
             if ($translated =~ /(?:^|\W)\*/) {
                 
@@ -250,7 +249,7 @@ WWW::Translate::Apertium - Open source machine translation
 
 =head1 VERSION
 
-Version 0.06 December 11, 2008
+Version 0.07 December 12, 2008
 
 
 =head1 SYNOPSIS
@@ -330,7 +329,7 @@ Currently, Apertium supports the following language pairs:
 =back
 
 
-- Single-direction
+- Single Direction
 
 =over 4
 
@@ -349,11 +348,11 @@ Currently, Apertium supports the following language pairs:
 =back
 
 
-B<NOTE>: Version 0.06 is a major update. The current module is based on the
-Apertium web service, which serves the translations faster than the previous
-web scraping approach.
+B<NOTE>: The underlying translation retrieval method changed in version 0.06.
+The current module is based on the Apertium web service, which serves the
+translations faster than the previous web scraping approach.
 
-Summary of changes that may have an impact on legacy code:
+Summary of changes since 0.05 that may have an impact on legacy code:
 
 - This module expects UTF-8 text and returns UTF-8 text. You can also send
 text encoded in Latin-1, but the support for Latin-1 will be phased out soon.
@@ -436,6 +435,8 @@ The valid values of this parameter are:
 
 =back
 
+These language pairs are stable versions. Other language pairs are currently
+under development.
 
 =item * C<< output >>
 
@@ -488,12 +489,19 @@ Apertium engine object:
 =head2 $engine->translate($string)
 
 Returns the translation of $string generated by Apertium, encoded as UTF-8.
-$string must be an UTF-8 encoded string. If the source text isn't encoded as
-UTF-8, you must convert it to that encoding before sending it to the machine
-translation engine. For this task you can use the Encode module or the PerlIO
-layer, if you are reading the text from a file.
 
-In case the server is down, it will show a warning and return C<undef>.
+The input $string must be an UTF-8 encoded string (for this task you can use
+the Encode module or the PerlIO layer, if you are reading the text from a file).
+
+If you are going to translate a literal string included in the code and then
+display the result in the output window of the code editor, then you should add
+the following statement to your code in order to avoid a "Wide character in
+print" warning:
+
+    binmode(STDOUT, ':utf8');
+
+In case the server is down, the C<translate> method will show a warning and
+return C<undef>.
 
 
 =head2 $engine->from_into($lang_pair)
